pub struct Extractor {
pub utility: ExtractorType,
pub extension: String,
pub arguments: Vec<String>,
pub exit_codes: Vec<i32>,
pub do_not_recurse: bool,
}Expand description
Describes extractors, both external and internal
Fields
utility: ExtractorTypeExternal command or internal function to execute
extension: StringFile extension expected by an external command
arguments: Vec<String>Arguments to pass to the external command
exit_codes: Vec<i32>A list of successful exit codes for the external command
do_not_recurse: boolSet to true to disable recursion into this extractor’s extracted files